# :studio_microphone: KONCERT : NICE 본인인증 스크래핑 </br> ![python >= 3.8](https://img.shields.io/badge/python-%3E%3D3.8-blue) [![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT) ![yark shaving](https://img.shields.io/badge/-yak%20shaving-red)
> NICE 본인인증 스크래핑 라이브러리

[ORCINUS: 해군교육사령부 모바일 인터넷편지 시스템](https://github.com/jiwonMe/orcinus)을 만들면서 본인 인증을 서비스 내부로 집어넣어야 했는데, 구현 과정에서 분리시킨 프로젝트입니다.

NICE 본인인증의 패킷 요청 및 응답을 분석하고, 

## 지원 서비스
- NICE 휴대폰본인확인

## 사용방법


## 참고

- [NICE아이디 휴대폰본인확인 서비스 설명 페이지](https://www.niceid.co.kr/prod_mobile.nc)